try_consume_own_context

Function try_consume_own_context 

pub fn try_consume_own_context<T>() -> Option<T>
where T: Clone + 'static,
Try to get a context value stored only in the current scope, without walking up to ancestors.